import React, { ReactNode, ComponentType, ComponentPropsWithRef } from 'react';
interface IProps {
    children?: ReactNode;
    component: string;
    fallbackComponent?: ComponentType<ComponentPropsWithRef<any>>;
    [property: string]: any;
}
/**
 * `CatalogComponent` is wrapped `withCatalog` by default and is capable of
 *
 * - rendering requested component from the catalog
 * - passing props to the requested component
 * - render a fallback component when `props.fallback` (node) is defined
 * - returns null (does not throw an error) when component does not exist in
 *   the catalog
 *
 * Example:
 * ```jsx
 * <CatalogComponent component="Button" hello="world" fallback={() => <div>not found</div>} />
 * ```
 *
 * `CatalogComponent` will now render the `<Button />` component (if it is part
 * of the catalog and pass `hello` as a prop to the Button). If the component
 * would not exist it will render the fallback.
 */
declare const CatalogComponent: React.ForwardRefExoticComponent<Pick<IProps, string | number> & React.RefAttributes<unknown>>;
export default CatalogComponent;
//# sourceMappingURL=catalog-component.d.ts.map